"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var view_1 = require("tns-core-modules/ui/core/view");
var app = require("tns-core-modules/application");
var permissions = require("nativescript-permissions");
function callIntent(context, intent, pickerType) {
    var requestPermissions = [android.Manifest.permission.WRITE_EXTERNAL_STORAGE];
    return permissions.requestPermission(requestPermissions, 'Need these permissions to access files').then(function () {
        return new Promise(function (resolve, reject) {
            var onEvent = function (e) {
                if (e.requestCode === pickerType) {
                    resolve(e);
                    app.android.off(app.AndroidApplication.activityResultEvent, onEvent);
                }
            };
            app.android.once(app.AndroidApplication.activityResultEvent, onEvent);
            context.startActivityForResult(intent, pickerType);
        });
    });
}
function getFilePath(context, uri) {
    if (android.os.Build.VERSION.SDK_INT >= 126) {
        var file = new java.io.File(uri.getPath());
        return file.getPath().split(':')[1];
    }
    var selection = null;
    var selectionArgs = null;
    if (android.os.Build.VERSION.SDK_INT >= 19 && android.provider.DocumentsContract.isDocumentUri(context.getApplicationContext(), uri)) {
        if (isExternalStorageDocument(uri)) {
            var docId = android.provider.DocumentsContract.getDocumentId(uri);
            var split = docId.split(':');
            return android.os.Environment.getExternalStorageDirectory() + '/' + split[1];
        }
        else if (isDownloadsDocument(uri)) {
            var id = android.provider.DocumentsContract.getDocumentId(uri);
            uri = android.content.ContentUris.withAppendedId(android.net.Uri.parse('content://downloads/public_downloads'), parseInt(id, 10));
        }
        else if (isMediaDocument(uri)) {
            var docId = android.provider.DocumentsContract.getDocumentId(uri);
            var split = docId.split(':');
            var type = split[0];
            if (type === 'image') {
                uri = android.provider.MediaStore.Images.Media.EXTERNAL_CONTENT_URI;
            }
            else if (type === 'video') {
                uri = android.provider.MediaStore.Video.Media.EXTERNAL_CONTENT_URI;
            }
            else if (type === 'audio') {
                uri = android.provider.MediaStore.Audio.Media.EXTERNAL_CONTENT_URI;
            }
            selection = '_id=?';
            selectionArgs = [split[1]];
        }
    }
    if (uri.getScheme().toLowerCase() === 'content') {
        if (isGooglePhotosUri(uri)) {
            return uri.getLastPathSegment();
        }
        var projection = [android.provider.MediaStore.Images.Media.DATA];
        var cursor = null;
        try {
            cursor = context.getContentResolver().query(uri, projection, selection, selectionArgs, null);
            var column_index = cursor.getColumnIndexOrThrow(android.provider.MediaStore.Images.Media.DATA);
            if (cursor.moveToFirst()) {
                return cursor.getString(column_index);
            }
        }
        catch (e) { }
    }
    else if (uri.getScheme().toLowerCase() === 'file') {
        return uri.getPath();
    }
    return null;
}
function isExternalStorageDocument(uri) {
    return uri.getAuthority() === 'com.android.externalstorage.documents';
}
function isDownloadsDocument(uri) {
    return uri.getAuthority() === 'com.android.providers.downloads.documents';
}
function isMediaDocument(uri) {
    return uri.getAuthority() === 'com.android.providers.media.documents';
}
function isGooglePhotosUri(uri) {
    return uri.getAuthority() === 'com.google.android.apps.photos.content';
}
function openFilePicker(params) {
    console.log('openFilePicker', params, view_1.isIOS);
    var extensions;
    if (params.extensions.length > 0) {
        extensions = Array.create(java.lang.String, params.extensions.length);
        for (var i = 0; i < params.extensions.length; i++) {
            extensions[i] = params.extensions[i];
        }
    }
    var context = app.android.foregroundActivity || app.android.startActivity;
    var FILE_CODE = 1231;
    var intent = new android.content.Intent(android.content.Intent.ACTION_GET_CONTENT);
    intent.setType(params.extensions ? params.extensions.join(' | ') : '*/*');
    intent.addCategory(android.content.Intent.CATEGORY_OPENABLE);
    intent.setAction(android.content.Intent.ACTION_OPEN_DOCUMENT);
    intent.putExtra(android.content.Intent.EXTRA_ALLOW_MULTIPLE, !!params.multipleSelection);
    return callIntent(context, intent, FILE_CODE).then(function (result) {
        if (result.resultCode === android.app.Activity.RESULT_OK) {
            if (result.intent != null) {
                var uri = result.intent.getData();
                return {
                    files: [getFilePath(context, uri)],
                    android: uri
                };
            }
            return {
                files: []
            };
        }
        else {
            throw new Error('no_file');
        }
    });
}
exports.openFilePicker = openFilePicker;
//# sourceMappingURL=filepicker.android.js.map