"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var utils = require("tns-core-modules/utils/utils");
var view_1 = require("tns-core-modules/ui/core/view");
var DocumentPickerDelegate = (function (_super) {
    __extends(DocumentPickerDelegate, _super);
    function DocumentPickerDelegate() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DocumentPickerDelegate.initWithResolveReject = function (resolve, reject) {
        var delegate = DocumentPickerDelegate.new();
        delegate._resolve = resolve;
        delegate._reject = reject;
        return delegate;
    };
    DocumentPickerDelegate.prototype.cleanup = function (controller) {
        this._resolve = null;
        this._reject = null;
        controller.delegate = null;
    };
    DocumentPickerDelegate.prototype.documentPickerDidPickDocumentAtURL = function (controller, url) {
        this._resolve({
            files: [url.absoluteString],
            ios: url
        });
        this.cleanup(controller);
    };
    DocumentPickerDelegate.prototype.documentPickerDidPickDocumentsAtURLs = function (controller, urls) {
        var output = [];
        for (var i = 0; i < urls.count; i++) {
            output.push(urls[i].absoluteString);
        }
        this._resolve({
            files: output,
            ios: urls
        });
        this.cleanup(controller);
    };
    DocumentPickerDelegate.prototype.documentPickerWasCancelled = function (controller) {
        this._reject('cancelled');
        this.cleanup(controller);
    };
    DocumentPickerDelegate.ObjCProtocols = [UIDocumentPickerDelegate];
    return DocumentPickerDelegate;
}(NSObject));
function openFilePicker(params) {
    console.log('openFilePicker', params, view_1.isIOS);
    var documentTypes;
    if (params.extensions && params.extensions.length > 0) {
        documentTypes = utils.ios.collections.jsArrayToNSArray(params.extensions);
    }
    return new Promise(function (resolve, reject) {
        console.log('arunning promise controller', params.extensions);
        var controller = UIDocumentPickerViewController.alloc().initWithDocumentTypesInMode(documentTypes, params.pickerMode !== undefined ? params.pickerMode : 0);
        controller.delegate = DocumentPickerDelegate.initWithResolveReject(resolve, reject);
        controller.allowsMultipleSelection = !!params.multipleSelection;
        console.log('about to open controller');
        var app = utils.ios.getter(UIApplication, UIApplication.sharedApplication);
        var window = app.keyWindow || (app.windows.count > 0 && app.windows[0]);
        var visibleVC = utils.ios.getVisibleViewController(window.rootViewController);
        visibleVC.presentViewControllerAnimatedCompletion(controller, true, null);
    });
}
exports.openFilePicker = openFilePicker;
//# sourceMappingURL=filepicker.ios.js.map